@@ -1,6 +1,10 @@
 """Test root selectors."""
 from .. import util
 import soupsieve as sv
+from bs4 import BeautifulSoup
+import pytest
+
+IFRAME_TEXT = BeautifulSoup('<iframe><div></div></iframe>', 'html.parser').iframe.text == '<div></div>'
 
 
 class TestRoot(util.TestCase):
@@ -65,7 +69,7 @@ class TestRoot(util.TestCase):
         self.assert_selector(
             self.MARKUP_IFRAME,
             ":root",
-            ["root", "root2"],
+            ["root"] if IFRAME_TEXT else ["root", "root2"],
             flags=util.PYHTML
         )
 
@@ -85,17 +89,18 @@ class TestRoot(util.TestCase):
         self.assert_selector(
             self.MARKUP_IFRAME,
             ":root div",
-            ["div", "div2", "other-div"],
+            ["div", "other-div"] if IFRAME_TEXT else ["div", "div2", "other-div"],
             flags=util.PYHTML
         )
 
         self.assert_selector(
             self.MARKUP_IFRAME,
             ":root > body > div",
-            ["div", "div2", "other-div"],
+            ["div", "other-div"] if IFRAME_TEXT else ["div", "div2", "other-div"],
             flags=util.PYHTML
         )
 
+    @pytest.mark.skipif(IFRAME_TEXT, reason="Requires old Python HTML handling")
     def test_iframe(self):
         """
         Test that we only count `iframe` as root since the scoped element is the root.
@@ -112,7 +117,6 @@ class TestRoot(util.TestCase):
 
         ids = [el['id'] for el in sv.select(':root > body > div', soup.iframe.html)]
         self.assertEqual(sorted(ids), sorted(['div2']))
-
     def test_no_root_double_tag(self):
         """Test when there is no root due to double root tags."""
 
